Crate kcr_dex_gpu_ninja_com

Crate kcr_dex_gpu_ninja_com 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the dex.gpu-ninja.com group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

dex.gpu-ninja.com/v1alpha1

  • DexIdentityProvider
  • DexOAuth2Client
  • DexUser

Modules

v1alpha1